// @ts-check
/**
 * Run `build` or `dev` with `SKIP_ENV_VALIDATION` to skip env validation.
 * This is especially useful for Docker builds.
 */
!process.env.SKIP_ENV_VALIDATION && (await import("./src/env/server.mjs"));

/** @type {import("next").NextConfig} */
if (
  !process.env.PUSHER_APP_ID ||
  !process.env.PUSHER_APP_KEY ||
  !process.env.PUSHER_APP_SECRET ||
  !process.env.PUSHER_APP_CLUSTER ||
  process.env.PUSHER_APP_TLS === undefined
) {
  console.error(
    "Error: One or more Pusher environment variables are missing. Please ensure that your .env.local file contains the required variables."
  );
  process.exit(1);
}
const config = {
  reactStrictMode: true,
  /* If trying out the experimental appDir, comment the i18n config out
   * @see https://github.com/vercel/next.js/issues/41980 */
  i18n: {
    locales: ["en"],
    defaultLocale: "en",
  },

  transpilePackages: ["daisyui"],
};
export default config;
